{
    "name": "{{ name }}",
    "display_name": "{{ display_name }}",
    "version": "{{ version }}",
    "visible": true,
    "description": "{{ description }}",
    "type": "{% if project_type == 'kit' %}kit{% else %}agent{% endif %}",
    "tags": ["python", "tool"],
    "cover": "https://img.shields.io/badge/{{ name.replace('-', '_') }}-tool-blue"
}